import { IntlShape } from '@braw/extended-intl';
import './messages-4c34bad5.js';
import './locales-8cef3d6b.js';

type ReverseMap<Map extends Record<keyof Map, PropertyKey>> = {
    [Value in Map[keyof Map]]: {
        [Key in keyof Map]: Map[Key] extends Value ? Key : never;
    }[keyof Map];
};

declare const formatAliases: {
    readonly formatCompactNumber: "compactNumber";
    readonly formatCustomMessage: "customMessage";
    readonly formatDate: "date";
    readonly formatDateTimeRange: "dateTimeRange";
    readonly formatDateToParts: "dateToParts";
    readonly formatDisplayName: "displayName";
    readonly formatList: "list";
    readonly formatListToParts: "listToParts";
    readonly formatMessage: "message";
    readonly formatNumber: "number";
    readonly formatNumberToParts: "numberToParts";
    readonly formatPlural: "plural";
    readonly formatRelativeTime: "relativeTime";
    readonly formatTime: "time";
    readonly formatTimeToParts: "timeToParts";
    readonly $ago: "$ago";
    readonly formatTimeDifference: "timeDifference";
};
type InvertedMapping = ReverseMap<typeof formatAliases>;
/**
 * Represents a map of formatting functions taken from {@link IntlShape} under a
 * shorter name. This is used to define `$fmt` global variable in Vue components
 * when the plugin is installed, as well as a return value for the
 * `useFormatters` runtime function.
 */
type FormatAliases<T> = {
    [K in keyof InvertedMapping]: IntlShape<T>[InvertedMapping[K]];
};
interface IntlPartial<T> {
    /**
     * Read-only map of formatting functions taken from {@link IntlShape}.
     *
     * @see {@link FormatAliases} for details.
     */
    get formats(): FormatAliases<T>;
    /** Active {@link IntlShape} instance. */
    get intl(): IntlShape<T>;
}

export { FormatAliases as F, IntlPartial as I };
