'use strict';

const IntlController = require('./shared/vue-intl-controller.4d517d70.cjs');
const ErrorEvent = require('./shared/vue-intl-controller.4dcf8c70.cjs');
require('@formatjs/intl-localematcher');
require('vue');
require('./shared/vue-intl-controller.27d34bfc.cjs');
require('@braw/extended-intl');
require('@braw/async-computed');

/** Represents options for the plugin. */

function createTranslateFunction(controller) {
  return function translateAndNormalize(descriptor, values, opts) {
    let result = '';
    const normalizedDescriptor = typeof descriptor === 'string' ? {
      id: descriptor,
      defaultMessage: controller.defaultMessages[descriptor]
    } : descriptor;
    result = controller.intl.formatMessage(normalizedDescriptor, values, opts);
    if (typeof result === 'string') {
      return result;
    }
    if (Array.isArray(result)) {
      let normalizedResult = '';
      for (const item of result) {
        normalizedResult += String(item);
      }
      return normalizedResult;
    }
    return String(result);
  };
}
function createPlugin(opts) {
  let controllerInstance = null;
  function retrieveController() {
    if (controllerInstance == null) {
      throw new Error('Controller is not initialised');
    }
    return controllerInstance;
  }
  let translateFunction = null;
  return {
    getOrCreateController() {
      if (controllerInstance == null) {
        controllerInstance = IntlController.createController(opts === null || opts === void 0 ? void 0 : opts.controllerOpts);
      }
      return controllerInstance;
    },
    getInjections() {
      const controller = this.getOrCreateController();
      if (translateFunction == null) {
        translateFunction = createTranslateFunction(controller);
      }
      return {
        $fmt: {
          configurable: true,
          get() {
            return retrieveController().formats;
          }
        },
        $t: {
          configurable: true,
          value: translateFunction
        },
        $i18n: {
          configurable: true,
          get: retrieveController
        }
      };
    },
    toProperties() {
      return Object.defineProperties(ErrorEvent.createHashMap(), this.getInjections());
    },
    install(vue) {
      var _opts$globalMixin, _opts$globalComponent;
      const injections = this.getInjections();
      if ((_opts$globalMixin = opts === null || opts === void 0 ? void 0 : opts.globalMixin) !== null && _opts$globalMixin !== void 0 ? _opts$globalMixin : true) {
        Object.defineProperties(vue.prototype, injections);
      }
      if ((opts === null || opts === void 0 ? void 0 : opts.injectInto) != null) {
        for (const injectionSite of opts.injectInto) {
          Object.defineProperties(injectionSite, injections);
        }
      }
      if ((_opts$globalComponent = opts === null || opts === void 0 ? void 0 : opts.globalComponent) !== null && _opts$globalComponent !== void 0 ? _opts$globalComponent : true) {
        vue.component('IntlFormatted', import('./chunks/IntlFormatted.cjs').then(module => module.IntlFormatted));
      }
    }
  };
}

exports.createPlugin = createPlugin;
