import { PluginObject } from 'vue';
import { C as ControllerConfiguration, I as IntlController } from './config-581f4135.js';
export { C as ControllerConfiguration } from './config-581f4135.js';
import { F as FormatAliases } from './intl-0143b193.js';
import { T as TranslateFunction } from './translateFunction-a13d14cd.js';
import './messages-4c34bad5.js';
import '@formatjs/intl';
import '@formatjs/icu-messageformat-parser';
import '@braw/extended-intl';
import './locales-8cef3d6b.js';
import './sources-02c94682.js';
import './ErrorEvent-032e1b23.js';
import '@braw/async-computed';
import 'intl-messageformat';

/** Represents options for the plugin. */
interface PluginOptions<ControllerType> {
    /** Options for the controller. */
    controllerOpts?: Partial<ControllerConfiguration<ControllerType>>;
    /**
     * Whether the `IntlFormatted` will be registered as a global component.
     *
     * Set this to `false` if you want to import the component manually.
     *
     * @default true // <IntlFormatted /> can be used without import
     */
    globalComponent?: boolean;
    /**
     * Whether the plugin's properties will be automatically injected to all
     * instances of Vue.
     *
     * Set this to `false` if you want to utilise composables instead.
     *
     * @default true // $t, $i18n, $fmt can be accessed via Vue
     */
    globalMixin?: boolean;
    /** An array containing all additional injection sites besides Vue. */
    injectInto?: object[];
}
/** Represents the default for all injection descriptors. */
type DefaultDescriptorOverrides = {
    configurable: true;
};
type GetterOf<T> = Omit<PropertyDescriptor, 'get' | keyof DefaultDescriptorOverrides> & DefaultDescriptorOverrides & {
    get(): T;
    set?: undefined;
};
type ValueOf<T> = Omit<PropertyDescriptor, 'value' | keyof DefaultDescriptorOverrides> & DefaultDescriptorOverrides & {
    value: T;
};
/** Represents global properties that are injected in `Vue.prototype`. */
interface PluginInjections<ControllerType> extends PropertyDescriptorMap {
    /** Injection for the formatting aliases. */
    $fmt: GetterOf<FormatAliases<ControllerType>>;
    /** Injection for the controller. */
    $i18n: GetterOf<IntlController<ControllerType>>;
    /** Injection for the translate function. */
    $t: ValueOf<TranslateFunction>;
}
type InjectedValues<Injections> = {
    [InjectionKey in keyof Injections as Injections[InjectionKey] extends {
        value: any;
    } ? InjectionKey : never]: Injections[InjectionKey] extends {
        value: infer ValueType;
    } ? ValueType : never;
};
type InjectedGetters<Injections> = {
    readonly [InjectionKey in keyof Injections as Injections[InjectionKey] extends {
        get(): any;
        set?: undefined;
    } ? InjectionKey : never]: Injections[InjectionKey] extends {
        get(): infer ValueType;
        set?: undefined;
    } ? ValueType : never;
};
type InjectedGettersAndSetters<Injections> = {
    [InjectionKey in keyof Injections as Injections[InjectionKey] extends {
        get(): any;
        set(value: any): void;
    } ? InjectionKey : never]: Injections[InjectionKey] extends {
        get(): infer ValueType;
        set(value: infer ValueType): void;
    } ? ValueType : never;
};
type InjectedProperties<ControllerType, Injections extends PluginInjections<ControllerType> = PluginInjections<ControllerType>> = InjectedValues<Injections> & InjectedGetters<Injections> & InjectedGettersAndSetters<Injections>;
interface Plugin<ControllerType> extends PluginObject<never> {
    getOrCreateController(config?: Partial<ControllerConfiguration<ControllerType>>): IntlController<ControllerType>;
    getInjections(): PluginInjections<ControllerType>;
    toProperties(): InjectedProperties<ControllerType>;
}
declare function createPlugin<ControllerType = string>(opts?: PluginOptions<ControllerType>): Plugin<ControllerType>;

export { InjectedProperties, Plugin, PluginInjections, PluginOptions, createPlugin };
