import { match } from '@formatjs/intl-localematcher';
import { isRef, shallowRef, computed, reactive, ref } from 'vue';
import { f as createHashMap, i as isAsyncEvent, E as ErrorEvent, d as isCanceled, e as LocaleLoadEvent, L as LocaleChangeEvent, A as AutomaticStateChangeEvent } from './vue-intl-controller.05cfe26e.mjs';
import { o as observe } from './vue-intl-controller.1929a7f2.mjs';
import { createIntlCache, createIntl } from '@braw/extended-intl';
import { asyncComputed } from '@braw/async-computed';

function newObject() {
  return Object.create(null);
}
function defineGetters(map) {
  const result = newObject();
  for (const property of [...Object.getOwnPropertyNames(map), ...Object.getOwnPropertySymbols(map)]) {
    Object.defineProperty(result, property, {
      configurable: true,
      get() {
        return map[property];
      }
    });
  }
  return result;
}
function defineRefGetters(referencesMap) {
  const result = createHashMap();
  for (const propertyKey of [...Object.getOwnPropertyNames(referencesMap), ...Object.getOwnPropertySymbols(referencesMap)]) {
    let normalizedKey = propertyKey;
    if (typeof normalizedKey === 'string' && normalizedKey.startsWith('$')) {
      normalizedKey = normalizedKey.slice(1);
    }
    Object.defineProperty(result, normalizedKey, {
      configurable: true,
      get: isRef(referencesMap[propertyKey]) ? function referenceGetter() {
        return referencesMap[propertyKey].value;
      } : function getter() {
        return referencesMap[propertyKey];
      }
    });
  }
  return result;
}

// imagine typescript had variadic merge haha kidding... unless 😳
function mergeDescriptors(_source1, _source2, _source3, _source4, _source5, _source6, _source7, _source8, _source9) {
  const result = newObject();

  // eslint-disable-next-line prefer-rest-params
  for (const object of arguments) {
    if (object == null) continue;
    for (const property of [...Object.getOwnPropertyNames(object), ...Object.getOwnPropertySymbols(object)]) {
      Object.defineProperty(result, property, Object.getOwnPropertyDescriptor(object, property));
    }
  }
  return result;
}

function usePrefersPartial($config) {
  const $sources = shallowRef([]);
  observe(() => $config.preferredLocaleSources, updatedSources => {
    const entries = $sources.value;
    const newEntries = [];
    if (updatedSources != null) {
      for (const entry of entries) {
        if (!updatedSources.includes(entry.source)) {
          var _entry$source$uninsta, _entry$source;
          (_entry$source$uninsta = (_entry$source = entry.source).uninstall) === null || _entry$source$uninsta === void 0 ? void 0 : _entry$source$uninsta.call(_entry$source);
          entry.installed = false;
        }
      }
      for (const source of updatedSources) {
        const entry = entries.find(it => it.source === source);
        if (entry == null || !entry.installed) {
          var _source$install;
          (_source$install = source.install) === null || _source$install === void 0 ? void 0 : _source$install.call(source);
        }
        newEntries.push({
          installed: true,
          source
        });
      }
    }
    $sources.value = newEntries;
  });
  const $preferredLocale = computed(() => {
    for (const entry of $sources.value) {
      const {
        source
      } = entry;
      let value;
      if (isRef(source.prefers)) {
        value = source.prefers.value;
      } else {
        value = source.prefers;
      }
      if (value == null) {
        continue;
      }
      return match(value, $config.locales.map(it => it.code), $config.defaultLocale);
    }
    return $config.defaultLocale;
  });
  function addSource(source) {
    let prepend = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    const filteredSources = [];

    // unshift is quite costly operation, better use two ifs
    if (prepend) filteredSources.push(source);
    if ($config.preferredLocaleSources != null) {
      for (const existingSource of $config.preferredLocaleSources) {
        if (existingSource === source) continue;
        filteredSources.push(existingSource);
      }
    }
    if (!prepend) filteredSources.push(source);
    $config.preferredLocaleSources = filteredSources;
  }
  function removeSource(source) {
    const filteredSources = [];
    let shallUpdate = false;
    for (const existingSource of $config.preferredLocaleSources) {
      if (existingSource === source) {
        shallUpdate = true;
      } else {
        filteredSources.push(existingSource);
      }
    }
    if (shallUpdate) {
      $config.preferredLocaleSources = filteredSources;
    }
  }
  const refs = {
    $preferredLocale
  };
  return mergeDescriptors(defineRefGetters(refs), {
    addSource,
    removeSource
  });
}

function createConfig(initialConfiguration) {
  var _initialConfiguration, _initialConfiguration2, _initialConfiguration3, _initialConfiguration4, _initialConfiguration5;
  const defaultLocale = (_initialConfiguration = initialConfiguration === null || initialConfiguration === void 0 ? void 0 : initialConfiguration.defaultLocale) !== null && _initialConfiguration !== void 0 ? _initialConfiguration : 'en-US';
  const locale = (_initialConfiguration2 = initialConfiguration === null || initialConfiguration === void 0 ? void 0 : initialConfiguration.locale) !== null && _initialConfiguration2 !== void 0 ? _initialConfiguration2 : defaultLocale;
  let locales = initialConfiguration === null || initialConfiguration === void 0 ? void 0 : initialConfiguration.locales;
  if (locales == null) {
    locales = [];
    locales.push({
      code: defaultLocale
    });
    if (locale !== defaultLocale) {
      locales.push({
        code: locale
      });
    }
  }
  return {
    defaultLocale,
    locale,
    locales,
    usePreferredLocale: (_initialConfiguration3 = initialConfiguration === null || initialConfiguration === void 0 ? void 0 : initialConfiguration.usePreferredLocale) !== null && _initialConfiguration3 !== void 0 ? _initialConfiguration3 : false,
    preferredLocaleSources: (_initialConfiguration4 = initialConfiguration === null || initialConfiguration === void 0 ? void 0 : initialConfiguration.preferredLocaleSources) !== null && _initialConfiguration4 !== void 0 ? _initialConfiguration4 : [],
    listen: (_initialConfiguration5 = initialConfiguration === null || initialConfiguration === void 0 ? void 0 : initialConfiguration.listen) !== null && _initialConfiguration5 !== void 0 ? _initialConfiguration5 : {}
  };
}
function useConfigPartial(initialConfiguration) {
  const $config = reactive(createConfig(initialConfiguration));
  const $intlLocale = computed(() => new Intl.Locale($config.locale));
  return mergeDescriptors(defineGetters({
    $config
  }), {
    get defaultLocale() {
      return $config.defaultLocale;
    }
  }, defineRefGetters({
    $intlLocale
  }));
}

function useLocaleDataPartial($config, locales) {
  function getLocale(localeCode) {
    const descriptor = locales.getLocaleDescriptor(localeCode);
    if (descriptor == null) {
      throw new Error(`Unknown locale "${localeCode}"`);
    }
    return locales.$locales.value.get(descriptor);
  }
  const $defaultMessages = computed(() => {
    var _getLocale$messages, _getLocale;
    return (_getLocale$messages = (_getLocale = getLocale($config.defaultLocale)) === null || _getLocale === void 0 ? void 0 : _getLocale.messages) !== null && _getLocale$messages !== void 0 ? _getLocale$messages : createHashMap();
  });
  const $messages = computed(() => {
    var _getLocale$messages2, _getLocale2;
    return (_getLocale$messages2 = (_getLocale2 = getLocale($config.locale)) === null || _getLocale2 === void 0 ? void 0 : _getLocale2.messages) !== null && _getLocale$messages2 !== void 0 ? _getLocale$messages2 : createHashMap();
  });
  const $defaultResources = computed(() => {
    var _getLocale$resources, _getLocale3;
    return (_getLocale$resources = (_getLocale3 = getLocale($config.defaultLocale)) === null || _getLocale3 === void 0 ? void 0 : _getLocale3.resources) !== null && _getLocale$resources !== void 0 ? _getLocale$resources : createHashMap();
  });
  const $resources = computed(() => {
    var _getLocale$resources2, _getLocale4;
    return (_getLocale$resources2 = (_getLocale4 = getLocale($config.locale)) === null || _getLocale4 === void 0 ? void 0 : _getLocale4.resources) !== null && _getLocale$resources2 !== void 0 ? _getLocale$resources2 : createHashMap();
  });
  const refs = {
    $defaultMessages,
    $messages,
    $defaultResources,
    $resources
  };
  return mergeDescriptors(defineGetters(refs), defineRefGetters(refs));
}

function useEventTargetPartial(controllerBox) {
  const eventRegister = new Map();

  // @ts-expect-error There appears to be a bug in TS that makes it think this type is incompatible.

  function addEventListener(type, listener, options) {
    if (!eventRegister.has(type)) {
      eventRegister.set(type, new Set());
    }
    const entries = eventRegister.get(type);
    for (const entry of entries) {
      if (entry.listener === listener) {
        entries.delete(entry);
      }
    }
    entries.add({
      listener,
      options: {
        ...options
      }
    });
  }

  // @ts-expect-error See line above addEventListener.

  function removeEventListener(type, listener) {
    const entries = eventRegister.get(type);
    if (entries == null) return;
    for (const value of entries) {
      if (value.listener === listener) {
        entries.delete(value);
      }
    }
  }
  function dispatchEvent(event) {
    const eventType = event.type;
    const entries = eventRegister.get(eventType);
    let canceled = false;
    const allowAsync = isAsyncEvent(event);

    // If you remember that async functions in JavaScript are essentially state
    // machines, this should not scare you.
    //
    // Basically, unless we are dealing with async event, this function will
    // never go beyond state 0, therefore it will act like a regular function
    // but with extra steps. Which is okay-ish compromise that helps us to avoid
    // code repetition.

    async function impl() {
      if (entries == null) return;
      const sortedListeners = [...entries.values()].sort((a, b) => {
        var _b$options$priority, _a$options$priority;
        return ((_b$options$priority = b.options.priority) !== null && _b$options$priority !== void 0 ? _b$options$priority : 0) - ((_a$options$priority = a.options.priority) !== null && _a$options$priority !== void 0 ? _a$options$priority : 0);
      });
      for (const entry of sortedListeners) {
        var _entry$options$always, _entry$options$once;
        if (canceled && !((_entry$options$always = entry.options.always) !== null && _entry$options$always !== void 0 ? _entry$options$always : false)) {
          continue;
        }
        try {
          const ret = entry.listener.call(controllerBox.value, event);
          if (allowAsync) await ret;
        } catch (err) {
          var _eventRegister$get$si, _eventRegister$get;
          if (((_eventRegister$get$si = (_eventRegister$get = eventRegister.get('error')) === null || _eventRegister$get === void 0 ? void 0 : _eventRegister$get.size) !== null && _eventRegister$get$si !== void 0 ? _eventRegister$get$si : 0) < 1) {
            // eslint-disable-next-line no-console
            console.error('Uncaught', err);
          } else {
            const wrappedError = new Error(`An error occurred while calling the event listener for "${eventType}"`, {
              cause: err
            });
            dispatchEvent(new ErrorEvent(wrappedError));
          }
        }
        if ((_entry$options$once = entry.options.once) !== null && _entry$options$once !== void 0 ? _entry$options$once : false) {
          entries.delete(entry);
        }
        if (!canceled) canceled = isCanceled(event);
      }
    }
    const completion = impl();
    if (entries != null && entries.size === 0) {
      eventRegister.delete(event.type);
    }
    if (allowAsync) {
      return completion.then(() => !canceled, () => false);
    } else {
      return !canceled;
    }
  }
  return {
    addEventListener,
    removeEventListener,
    dispatchEvent
  };
}

const formatAliases = {
  formatCompactNumber: 'compactNumber',
  formatCustomMessage: 'customMessage',
  formatDate: 'date',
  formatDateTimeRange: 'dateTimeRange',
  formatDateToParts: 'dateToParts',
  formatDisplayName: 'displayName',
  formatList: 'list',
  formatListToParts: 'listToParts',
  formatMessage: 'message',
  formatNumber: 'number',
  formatNumberToParts: 'numberToParts',
  formatPlural: 'plural',
  formatRelativeTime: 'relativeTime',
  formatTime: 'time',
  formatTimeToParts: 'timeToParts',
  $ago: '$ago',
  formatTimeDifference: 'timeDifference'
};
// ~~~~~~~
// NOTE: You might need to remove as const so auto-complete works, also you can't place it after satisfier, that's not supported :(

function useIntlPartial($config, $messages) {
  const $formats = ref(createHashMap());
  const intlCache = createIntlCache();
  const $intl = computed(() => createIntl({
    locale: $config.locale,
    defaultLocale: $config.defaultLocale,
    messages: $messages.value
  }, intlCache));
  observe($intl, intl => {
    const formats = $formats.value;
    for (const [intlProp, alias] of Object.entries(formatAliases)) {
      formats[alias] = intl[intlProp];
    }
  });
  return defineRefGetters({
    $formats,
    $intl
  });
}

/**
 * Given the iterator, iterates over it in attempt to find {@link search}.
 *
 * @param iterator Iterator to iterate over.
 * @param search Item to search for.
 * @returns `true` if item is found, otherwise `false`.
 */
function includes(iterator, search) {
  for (const item of iterator) {
    if (item === search) return true;
  }
  return false;
}

/**
 * Given the iterator, iterates over it in attempt to find item for which the
 * predicate function would return `true`.
 *
 * @param iterator Iterator to iterate over.
 * @param predicate Predicate that returns `true` for matching item, and `false`
 *   for other items.
 * @returns Item for which the predicate returned `true`, otherwise `undefined`.
 */
function find(iterator, predicate) {
  for (const item of iterator) {
    if (predicate(item)) return item;
  }
  return undefined;
}

function useLocalesPartial(initialLocaleData, $config, eventTarget, prefersPartial) {
  const $locales = ref(new Map(initialLocaleData));
  observe(() => $config.locales, newLocales => {
    const knownLocales = new Map($locales.value);
    const knownLocaleCodes = new Set();
    for (const locale of newLocales) {
      if (knownLocaleCodes.has(locale.code)) {
        throw new Error(`Duplicate locale ${locale.code} has been detected`);
      }
      knownLocaleCodes.add(locale.code);
      if (includes(knownLocales.keys(), locale)) continue;
      knownLocales.set(locale, {
        messages: createHashMap(),
        resources: createHashMap()
      });
    }
    for (const knownLocale of knownLocales.keys()) {
      if (!newLocales.includes(knownLocale)) {
        knownLocales.delete(knownLocale);
      }
    }
    $locales.value = knownLocales;
  });
  function getLocaleDescriptor(localeCode) {
    return find($locales.value.keys(), descriptor => descriptor.code === localeCode);
  }
  function getLocale(localeDescriptor) {
    return $locales.value.get(localeDescriptor);
  }
  function getLocaleByCode(localeCode) {
    const descriptor = getLocaleDescriptor(localeCode);
    if (descriptor == null) return undefined;
    return getLocale(descriptor);
  }
  const $automatic = computed(() => $config.usePreferredLocale);
  const $automaticLocaleCode = ref(null);
  const $locale = computed(() => {
    var _$automaticLocaleCode;
    return (_$automaticLocaleCode = $automaticLocaleCode.value) !== null && _$automaticLocaleCode !== void 0 ? _$automaticLocaleCode : $config.locale;
  });
  let lastLoadedLocale = null;
  const $loading = asyncComputed({
    watch() {
      return getLocaleDescriptor($locale.value);
    },
    async get(descriptor) {
      if (descriptor == null) {
        throw new Error('No locale descriptor exists for the current locale');
      }
      const locale = getLocale(descriptor);
      if (locale == null) {
        throw new Error('No locale exists for the active locale descriptor');
      }
      if (lastLoadedLocale === locale) return;
      lastLoadedLocale = locale;
      const event = new LocaleLoadEvent(descriptor, locale);
      this.onCancel(event.cancel.bind(null));
      if (!(await eventTarget.dispatchEvent(event))) {
        throw new Error(`Cannot load locale messages for the locale "${descriptor.code}": load event is cancelled`);
      }
      Object.assign(locale, event.collect());
    }
  });
  observe(() => ({
    isEnabled: $automatic.value,
    locale: prefersPartial.preferredLocale
  }), (_ref, previousState) => {
    let {
      isEnabled,
      locale
    } = _ref;
    const wasEnabled = previousState === null || previousState === void 0 ? void 0 : previousState.isEnabled;
    if (isEnabled && !wasEnabled) {
      var _previousState$locale;
      const previousLocale = (_previousState$locale = previousState === null || previousState === void 0 ? void 0 : previousState.locale) !== null && _previousState$locale !== void 0 ? _previousState$locale : $config.locale;
      const languageSwitchCanceled = !eventTarget.dispatchEvent(new LocaleChangeEvent(previousLocale, locale, true));
      if (languageSwitchCanceled) return;
      $automaticLocaleCode.value = locale;
    } else if (!isEnabled && wasEnabled) {
      $automaticLocaleCode.value = null;
    }
  });
  function addLocale(descriptor, force) {
    const normalizedDescriptor = typeof descriptor === 'string' ? {
      code: descriptor
    } : descriptor;
    const newLocales = [];
    for (const locale of $config.locales) {
      if (locale.code === normalizedDescriptor.code) {
        if (!force) {
          throw new Error(`Locale "${normalizedDescriptor.code}" already exists`);
        }
      } else {
        newLocales.push(locale);
      }
    }
    newLocales.push(normalizedDescriptor);
    $config.locales = newLocales;
    return normalizedDescriptor;
  }
  function removeLocale(descriptor) {
    var _$config$locales$spli;
    let index;
    if (typeof descriptor === 'string') {
      index = $config.locales.findIndex(locale => locale.code === descriptor);
    } else {
      index = $config.locales.findIndex(locale => locale === descriptor);
    }
    return index === -1 ? null : (_$config$locales$spli = $config.locales.splice(index, 1)[0]) !== null && _$config$locales$spli !== void 0 ? _$config$locales$spli : null;
  }
  function addMessages(descriptor, messages) {
    let locale;
    if (typeof descriptor === 'string') {
      locale = getLocaleByCode(descriptor);
      if (locale == null) {
        throw new Error(`Locale with code "${descriptor}" does not exist`);
      }
    } else {
      locale = getLocale(descriptor);
      if (locale == null) {
        throw new Error(`Locale with the provided descriptor (for ${descriptor.code}) does not exist`);
      }
    }
    if (locale.messages == null) {
      locale.messages = createHashMap();
    }
    Object.assign(locale.messages, messages);
  }
  async function changeLocale(localeCode) {
    if ($config.locale === localeCode) {
      return;
    }
    if (localeCode === 'auto') {
      if (!eventTarget.dispatchEvent(new AutomaticStateChangeEvent(true))) {
        throw new Error('Enabling of automatic mode has been cancelled');
      }
    } else {
      const autoSwitchOffCanceled = eventTarget.dispatchEvent(new AutomaticStateChangeEvent(false));
      if ($automatic.value && !autoSwitchOffCanceled) {
        return;
      }
      const localeChangeCanceled = !eventTarget.dispatchEvent(new LocaleChangeEvent($config.locale, localeCode, false));
      if (localeChangeCanceled) {
        throw new Error(`Locale change to "${localeCode}" was cancelled`);
      }
      $config.locale = localeCode;
    }
    $config.usePreferredLocale = localeCode === 'auto';
    await $loading.promise;
  }
  async function waitUntilReady() {
    await $loading.promise;
  }
  return mergeDescriptors(defineGetters({
    $loading,
    $locales
  }), defineRefGetters({
    $automatic,
    $locale
  }), {
    get ready() {
      return $loading.fulfilled;
    },
    getLocaleDescriptor,
    addLocale,
    removeLocale,
    addMessages,
    changeLocale,
    waitUntilReady
  });
}

/**
 * Performs equality by iterating through keys on an object.
 *
 * @license MIT Copyright (c) Meta Platforms, Inc. and affiliates.
 *   https://github.com/facebook/react/blob/ff9f943741671b6d83d732b2131d3f7e7d3c54c8/LICENSE
 * @returns `false` when any key has values which are not strictly equal between
 *   the arguments, or `true` when the values of all keys are strictly equal.
 */
function shallowEqual(objA, objB) {
  if (Object.is(objA, objB)) {
    return true;
  }
  if (typeof objA !== 'object' || objA === null || typeof objB !== 'object' || objB === null) {
    return false;
  }
  const keysA = Object.keys(objA);
  const keysB = Object.keys(objB);
  if (keysA.length !== keysB.length) {
    return false;
  }

  // Test for A's keys different from B.
  for (let i = 0; i < keysA.length; i++) {
    if (!Object.prototype.hasOwnProperty.call(objB, keysA[i]) || !Object.is(objA[keysA[i]], objB[keysA[i]])) {
      return false;
    }
  }
  return true;
}

function keys(value) {
  return Object.keys(value);
}
function isListenerWithOptions(value) {
  return typeof value === 'object' && value != null && !Array.isArray(value) && Object.prototype.hasOwnProperty.call(value, 'listener');
}
function normalizeListeners(listenersRaw) {
  const listeners = [];
  if (listenersRaw == null) return listeners;
  if (isListenerWithOptions(listenersRaw)) {
    listeners.push(listenersRaw);
    return listeners;
  }
  if (Array.isArray(listenersRaw)) {
    for (const rawListener of listenersRaw) {
      if (isListenerWithOptions(rawListener)) {
        listeners.push(rawListener);
      } else {
        listeners.push({
          listener: rawListener
        });
      }
    }
  } else {
    listeners.push({
      listener: listenersRaw
    });
  }
  return listeners;
}
function useDeclarativeEvents($config, eventTarget) {
  const knownListenersByType = Object.create(null);
  function getKnownListeners(type) {
    if (knownListenersByType[type] == null) {
      knownListenersByType[type] = [];
    }
    return knownListenersByType[type];
  }
  function evict(type, item) {
    const knownListeners = knownListenersByType[type];
    if (knownListeners == null) return;
    const itemIndex = knownListeners.findIndex(it => it === item);
    if (itemIndex !== -1) knownListeners.splice(itemIndex, 1);
    if (knownListeners.length === 0) delete knownListenersByType[type];
  }
  observe(() => $config.listen, listenersByType => {
    for (const eventType of keys(listenersByType)) {
      if (listenersByType[eventType] == null) continue;
      const knownListeners = getKnownListeners(eventType);
      const listeners = normalizeListeners(listenersByType[eventType]);
      for (const listenerItem of listeners) {
        var _listenerItem$options, _listenerItem$options2;
        const knownListenerItemIndex = knownListeners.findIndex(it => it.listener === listenerItem.listener);
        if (knownListenerItemIndex !== -1) {
          const knownListenerItem = knownListeners[knownListenerItemIndex];
          if (shallowEqual(listenerItem.options, knownListenerItem.options)) {
            continue;
          }
          eventTarget.removeEventListener(eventType, listenerItem.listener);
          knownListeners.splice(knownListenerItemIndex, 1);
        }
        let wrappedListener;
        if ((_listenerItem$options = (_listenerItem$options2 = listenerItem.options) === null || _listenerItem$options2 === void 0 ? void 0 : _listenerItem$options2.once) !== null && _listenerItem$options !== void 0 ? _listenerItem$options : false) {
          const originalListener = listenerItem.listener;
          wrappedListener = function () {
            for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
              args[_key] = arguments[_key];
            }
            try {
              return originalListener.call(this, ...args);
            } finally {
              evict(eventType, listenerItem);
            }
          };
        } else {
          wrappedListener = listenerItem.listener;
        }
        eventTarget.addEventListener(eventType, wrappedListener, listenerItem.options);
        knownListeners.push(listenerItem);
      }
      for (let i = 0; i < knownListeners.length; i++) {
        const knownListenerItem = knownListeners[i];
        const activeListenerItemIndex = listeners.findIndex(it => it.listener === knownListenerItem.listener && shallowEqual(it.options, knownListenerItem.options));
        if (activeListenerItemIndex === -1) {
          eventTarget.removeEventListener(eventType, knownListenerItem.listener);
          knownListeners.splice(i, 1);
          i -= 1;
        }
      }
      if (knownListeners.length === 0) delete knownListenersByType[eventType];
    }
  });
}

function createController(initialConfiguration, initialLocaleData) {
  const controllerBox = {
    value: null
  };
  const configPartial = useConfigPartial(initialConfiguration);
  const eventTargetPartial = useEventTargetPartial(controllerBox);
  useDeclarativeEvents(configPartial.$config, eventTargetPartial);
  const prefersPartial = usePrefersPartial(configPartial.$config);
  const localesPartial = useLocalesPartial(initialLocaleData, configPartial.$config, eventTargetPartial, prefersPartial);
  const dataPartial = useLocaleDataPartial(configPartial.$config, localesPartial);
  const intlPartial = useIntlPartial(configPartial.$config, dataPartial.$messages);
  controllerBox.value = mergeDescriptors(configPartial, localesPartial, intlPartial, dataPartial, prefersPartial, eventTargetPartial);
  return controllerBox.value;
}

export { createController as c };
