import { CompactNumber } from '@braw/extended-intl';
import { PrimitiveType, FormatXMLElementFn } from 'intl-messageformat';
import { M as MessageValueType } from '../messages-4c34bad5.js';
import '@formatjs/intl';
import '@formatjs/icu-messageformat-parser';
import 'vue';

/**
 * Represents a value for unknown argument. This is a last resort type to use,
 * which allows both wrappers and regular values. It's primary use is when type
 * cannot be determined from the use of argument.
 */
type AnyArgument = PrimitiveType | MessageValueType | FormatXMLElementFn<MessageValueType>;
/**
 * Represents a value for a value argument.
 *
 * Example of argument: `{value}`.
 */
type ValueArgument = PrimitiveType | MessageValueType;
/**
 * Represents a value for an rich text formatting argument.
 *
 * Example of argument: `<value></value>`.
 */
type RichArgument = FormatXMLElementFn<MessageValueType>;
/**
 * Represents a value for a number argument.
 *
 * Example of argument: `{value, number}`.
 */
type NumberArgument = string | number | bigint | CompactNumber;
/**
 * Represents a value for a date or time argument.
 *
 * Example of arguments:
 *
 * - `{value, date}`
 * - `{value, time}`
 */
type DateArgument = Date | string | number;
/** Represents a valid keyword in selector. */
type _SelectKeywordAcceptable = string | number;
/**
 * Represents a value for a select argument where `KeywordUnion` is a union of
 * string/number keywords.
 *
 * Example of argument: `{value, select, cat {Cat} other {Animal}}`.
 *
 * For the example above the `KeywordUnion` must be: `'cat' | 'other'`.
 */
type SelectArgument<KeywordUnion> = KeywordUnion | (_SelectKeywordAcceptable & Record<never, never>);
declare const _default: {};

export { AnyArgument, DateArgument, NumberArgument, RichArgument, SelectArgument, ValueArgument, _default as default };
